# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'MaintenancePropertiesState',
    'MaxmemoryPolicy',
    'OwnerType',
    'Plan',
    'RedisDetailMaintenancePropertiesState',
    'RedisDetailPlan',
    'RedisDetailRegion',
    'RedisDetailStatus',
    'RedisPlan',
    'RedisRegion',
    'RedisStatus',
    'Region',
    'Status',
]


class MaintenancePropertiesState(str, Enum):
    SCHEDULED = "scheduled"
    IN_PROGRESS = "in_progress"
    USER_FIX_REQUIRED = "user_fix_required"
    CANCELLED = "cancelled"
    SUCCEEDED = "succeeded"
    FAILED = "failed"


class MaxmemoryPolicy(str, Enum):
    """
    The eviction policy for the Redis instance
    """
    NOEVICTION = "noeviction"
    ALLKEYS_LFU = "allkeys_lfu"
    ALLKEYS_LRU = "allkeys_lru"
    ALLKEYS_RANDOM = "allkeys_random"
    VOLATILE_LFU = "volatile_lfu"
    VOLATILE_LRU = "volatile_lru"
    VOLATILE_RANDOM = "volatile_random"
    VOLATILE_TTL = "volatile_ttl"


class OwnerType(str, Enum):
    USER = "user"
    TEAM = "team"


class Plan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"


class RedisDetailMaintenancePropertiesState(str, Enum):
    SCHEDULED = "scheduled"
    IN_PROGRESS = "in_progress"
    USER_FIX_REQUIRED = "user_fix_required"
    CANCELLED = "cancelled"
    SUCCEEDED = "succeeded"
    FAILED = "failed"


class RedisDetailPlan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"


class RedisDetailRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class RedisDetailStatus(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"


class RedisPlan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"


class RedisRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class RedisStatus(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"


class Region(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class Status(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from .. import services

apiKey: Optional[str]
"""
The Render API key
"""

clearCacheOnServiceUpdateDeployments: Optional[str]
"""
When a service is updated, a deployment is automatically triggered. This variable controls whether or not the service cache should be cleared upon deployment.
"""




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload, Awaitable
from .. import _utilities

__all__ = [
    'SecretFile',
    'AwaitableSecretFile',
    'get_secret_file',
    'get_secret_file_output',
]

@pulumi.output_type
class SecretFile:
    def __init__(__self__, content=None, name=None):
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def content(self) -> str:
        return pulumi.get(self, "content")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")


class AwaitableSecretFile(SecretFile):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return SecretFile(
            content=self.content,
            name=self.name)


def get_secret_file(secret_file_name: Optional[str] = None,
                    service_id: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableSecretFile:
    """
    Use this data source to access information about an existing resource.

    :param str secret_file_name: The file name of the secret file
    :param str service_id: The ID of the service
    """
    __args__ = dict()
    __args__['secretFileName'] = secret_file_name
    __args__['serviceId'] = service_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:services:getSecretFile', __args__, opts=opts, typ=SecretFile).value

    return AwaitableSecretFile(
        content=pulumi.get(__ret__, 'content'),
        name=pulumi.get(__ret__, 'name'))


@_utilities.lift_output_func(get_secret_file)
def get_secret_file_output(secret_file_name: Optional[pulumi.Input[str]] = None,
                           service_id: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[SecretFile]:
    """
    Use this data source to access information about an existing resource.

    :param str secret_file_name: The file name of the secret file
    :param str service_id: The ID of the service
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .env_group import *
from .get_env_group import *
from .get_env_group_env_var import *
from .get_env_group_secret_file import *
from .link_service_to_env_group import *
from .list_env_groups import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ListActiveConnectionsItemProperties',
    'ListActiveConnectionsItemPropertiesLabelsItemProperties',
    'ListActiveConnectionsItemPropertiesValuesItemProperties',
    'ListReplicationLagItemProperties',
    'ListReplicationLagItemPropertiesLabelsItemProperties',
    'ListReplicationLagItemPropertiesValuesItemProperties',
]

@pulumi.output_type
class ListActiveConnectionsItemProperties(dict):
    """
    A time series data point
    """
    def __init__(__self__, *,
                 labels: Sequence['outputs.ListActiveConnectionsItemPropertiesLabelsItemProperties'],
                 unit: str,
                 values: Sequence['outputs.ListActiveConnectionsItemPropertiesValuesItemProperties']):
        """
        A time series data point
        :param Sequence['ListActiveConnectionsItemPropertiesLabelsItemProperties'] labels: List of labels describing the time series
        :param Sequence['ListActiveConnectionsItemPropertiesValuesItemProperties'] values: The values of the time series
        """
        pulumi.set(__self__, "labels", labels)
        pulumi.set(__self__, "unit", unit)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def labels(self) -> Sequence['outputs.ListActiveConnectionsItemPropertiesLabelsItemProperties']:
        """
        List of labels describing the time series
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def unit(self) -> str:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def values(self) -> Sequence['outputs.ListActiveConnectionsItemPropertiesValuesItemProperties']:
        """
        The values of the time series
        """
        return pulumi.get(self, "values")


@pulumi.output_type
class ListActiveConnectionsItemPropertiesLabelsItemProperties(dict):
    """
    A time series datapoint label
    """
    def __init__(__self__, *,
                 field: str,
                 value: str):
        """
        A time series datapoint label
        """
        pulumi.set(__self__, "field", field)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def field(self) -> str:
        return pulumi.get(self, "field")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class ListActiveConnectionsItemPropertiesValuesItemProperties(dict):
    """
    A time series datapoint value
    """
    def __init__(__self__, *,
                 timestamp: str,
                 value: float):
        """
        A time series datapoint value
        """
        pulumi.set(__self__, "timestamp", timestamp)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def timestamp(self) -> str:
        return pulumi.get(self, "timestamp")

    @property
    @pulumi.getter
    def value(self) -> float:
        return pulumi.get(self, "value")


@pulumi.output_type
class ListReplicationLagItemProperties(dict):
    """
    A time series data point
    """
    def __init__(__self__, *,
                 labels: Sequence['outputs.ListReplicationLagItemPropertiesLabelsItemProperties'],
                 unit: str,
                 values: Sequence['outputs.ListReplicationLagItemPropertiesValuesItemProperties']):
        """
        A time series data point
        :param Sequence['ListReplicationLagItemPropertiesLabelsItemProperties'] labels: List of labels describing the time series
        :param Sequence['ListReplicationLagItemPropertiesValuesItemProperties'] values: The values of the time series
        """
        pulumi.set(__self__, "labels", labels)
        pulumi.set(__self__, "unit", unit)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def labels(self) -> Sequence['outputs.ListReplicationLagItemPropertiesLabelsItemProperties']:
        """
        List of labels describing the time series
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def unit(self) -> str:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def values(self) -> Sequence['outputs.ListReplicationLagItemPropertiesValuesItemProperties']:
        """
        The values of the time series
        """
        return pulumi.get(self, "values")


@pulumi.output_type
class ListReplicationLagItemPropertiesLabelsItemProperties(dict):
    """
    A time series datapoint label
    """
    def __init__(__self__, *,
                 field: str,
                 value: str):
        """
        A time series datapoint label
        """
        pulumi.set(__self__, "field", field)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def field(self) -> str:
        return pulumi.get(self, "field")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class ListReplicationLagItemPropertiesValuesItemProperties(dict):
    """
    A time series datapoint value
    """
    def __init__(__self__, *,
                 timestamp: str,
                 value: float):
        """
        A time series datapoint value
        """
        pulumi.set(__self__, "timestamp", timestamp)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def timestamp(self) -> str:
        return pulumi.get(self, "timestamp")

    @property
    @pulumi.getter
    def value(self) -> float:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload, Awaitable
from .. import _utilities

__all__ = [
    'EnvVar',
    'AwaitableEnvVar',
    'get_env_group_env_var',
    'get_env_group_env_var_output',
]

@pulumi.output_type
class EnvVar:
    def __init__(__self__, key=None, value=None):
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


class AwaitableEnvVar(EnvVar):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return EnvVar(
            key=self.key,
            value=self.value)


def get_env_group_env_var(env_group_id: Optional[str] = None,
                          env_var_key: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableEnvVar:
    """
    Use this data source to access information about an existing resource.

    :param str env_group_id: Filter for resources that belong to an environment group
    :param str env_var_key: The name of the environment variable
    """
    __args__ = dict()
    __args__['envGroupId'] = env_group_id
    __args__['envVarKey'] = env_var_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:env-groups:getEnvGroupEnvVar', __args__, opts=opts, typ=EnvVar).value

    return AwaitableEnvVar(
        key=pulumi.get(__ret__, 'key'),
        value=pulumi.get(__ret__, 'value'))


@_utilities.lift_output_func(get_env_group_env_var)
def get_env_group_env_var_output(env_group_id: Optional[pulumi.Input[str]] = None,
                                 env_var_key: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[EnvVar]:
    """
    Use this data source to access information about an existing resource.

    :param str env_group_id: Filter for resources that belong to an environment group
    :param str env_var_key: The name of the environment variable
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = ['RunCronJobArgs', 'RunCronJob']

@pulumi.input_type
class RunCronJobArgs:
    def __init__(__self__, *,
                 cron_job_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RunCronJob resource.
        :param pulumi.Input[str] cron_job_id: The ID of the cron job
        """
        if cron_job_id is not None:
            pulumi.set(__self__, "cron_job_id", cron_job_id)

    @property
    @pulumi.getter(name="cronJobId")
    def cron_job_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the cron job
        """
        return pulumi.get(self, "cron_job_id")

    @cron_job_id.setter
    def cron_job_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron_job_id", value)


class RunCronJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_job_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a RunCronJob resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cron_job_id: The ID of the cron job
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RunCronJobArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a RunCronJob resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param RunCronJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RunCronJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_job_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RunCronJobArgs.__new__(RunCronJobArgs)

            __props__.__dict__["cron_job_id"] = cron_job_id
            __props__.__dict__["canceled_by"] = None
            __props__.__dict__["finished_at"] = None
            __props__.__dict__["started_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["triggered_by"] = None
        super(RunCronJob, __self__).__init__(
            'render:cron-jobs:RunCronJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'RunCronJob':
        """
        Get an existing RunCronJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = RunCronJobArgs.__new__(RunCronJobArgs)

        __props__.__dict__["canceled_by"] = None
        __props__.__dict__["finished_at"] = None
        __props__.__dict__["started_at"] = None
        __props__.__dict__["status"] = None
        __props__.__dict__["triggered_by"] = None
        return RunCronJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canceledBy")
    def canceled_by(self) -> pulumi.Output[Optional[str]]:
        """
        user who cancelled the cron job run
        """
        return pulumi.get(self, "canceled_by")

    @property
    @pulumi.getter(name="finishedAt")
    def finished_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "finished_at")

    @property
    @pulumi.getter(name="startedAt")
    def started_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "started_at")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['Status']:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="triggeredBy")
    def triggered_by(self) -> pulumi.Output[Optional[str]]:
        """
        user who triggered the cron job run
        """
        return pulumi.get(self, "triggered_by")




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'GetPostgresRecoveryInfoPropertiesRecoveryStatus',
    'OwnerType',
    'Plan',
    'PostgresDetailPlan',
    'PostgresDetailRegion',
    'PostgresDetailRole',
    'PostgresDetailStatus',
    'PostgresDetailSuspended',
    'PostgresDetailSuspendersItem',
    'PostgresDetailVersion',
    'PostgresPlan',
    'PostgresRegion',
    'PostgresRole',
    'PostgresStatus',
    'PostgresSuspended',
    'PostgresSuspendersItem',
    'PostgresVersion',
    'RecoverPostgresSuspended',
    'RedisDetailpropertiesmaintenanceState',
    'Region',
    'Role',
    'Status',
    'Suspended',
    'SuspendersItem',
    'Version',
]


class GetPostgresRecoveryInfoPropertiesRecoveryStatus(str, Enum):
    """
    Availability of point-in-time recovery.
    """
    AVAILABLE = "AVAILABLE"
    BACKUP_NOT_READY = "BACKUP_NOT_READY"
    NOT_AVAILABLE = "NOT_AVAILABLE"


class OwnerType(str, Enum):
    USER = "user"
    TEAM = "team"


class Plan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"
    BASIC256MB = "basic_256mb"
    BASIC1GB = "basic_1gb"
    BASIC4GB = "basic_4gb"
    PRO4GB = "pro_4gb"
    PRO8GB = "pro_8gb"
    PRO16GB = "pro_16gb"
    PRO32GB = "pro_32gb"
    PRO64GB = "pro_64gb"
    PRO128GB = "pro_128gb"
    PRO192GB = "pro_192gb"
    PRO256GB = "pro_256gb"
    PRO384GB = "pro_384gb"
    PRO512GB = "pro_512gb"
    ACCELERATED16GB = "accelerated_16gb"
    ACCELERATED32GB = "accelerated_32gb"
    ACCELERATED64GB = "accelerated_64gb"
    ACCELERATED128GB = "accelerated_128gb"
    ACCELERATED256GB = "accelerated_256gb"
    ACCELERATED384GB = "accelerated_384gb"
    ACCELERATED512GB = "accelerated_512gb"
    ACCELERATED768GB = "accelerated_768gb"
    ACCELERATED1024GB = "accelerated_1024gb"


class PostgresDetailPlan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"
    BASIC256MB = "basic_256mb"
    BASIC1GB = "basic_1gb"
    BASIC4GB = "basic_4gb"
    PRO4GB = "pro_4gb"
    PRO8GB = "pro_8gb"
    PRO16GB = "pro_16gb"
    PRO32GB = "pro_32gb"
    PRO64GB = "pro_64gb"
    PRO128GB = "pro_128gb"
    PRO192GB = "pro_192gb"
    PRO256GB = "pro_256gb"
    PRO384GB = "pro_384gb"
    PRO512GB = "pro_512gb"
    ACCELERATED16GB = "accelerated_16gb"
    ACCELERATED32GB = "accelerated_32gb"
    ACCELERATED64GB = "accelerated_64gb"
    ACCELERATED128GB = "accelerated_128gb"
    ACCELERATED256GB = "accelerated_256gb"
    ACCELERATED384GB = "accelerated_384gb"
    ACCELERATED512GB = "accelerated_512gb"
    ACCELERATED768GB = "accelerated_768gb"
    ACCELERATED1024GB = "accelerated_1024gb"


class PostgresDetailRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class PostgresDetailRole(str, Enum):
    PRIMARY = "primary"
    REPLICA = "replica"


class PostgresDetailStatus(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"


class PostgresDetailSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class PostgresDetailSuspendersItem(str, Enum):
    ADMIN = "admin"
    BILLING = "billing"
    USER = "user"
    PARENT_SERVICE = "parent_service"
    UNKNOWN = "unknown"


class PostgresDetailVersion(str, Enum):
    """
    The PostgreSQL version
    """
    POSTGRES_DETAIL_VERSION_11 = "11"
    POSTGRES_DETAIL_VERSION_12 = "12"
    POSTGRES_DETAIL_VERSION_13 = "13"
    POSTGRES_DETAIL_VERSION_14 = "14"
    POSTGRES_DETAIL_VERSION_15 = "15"
    POSTGRES_DETAIL_VERSION_16 = "16"


class PostgresPlan(str, Enum):
    FREE = "free"
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    CUSTOM = "custom"
    BASIC256MB = "basic_256mb"
    BASIC1GB = "basic_1gb"
    BASIC4GB = "basic_4gb"
    PRO4GB = "pro_4gb"
    PRO8GB = "pro_8gb"
    PRO16GB = "pro_16gb"
    PRO32GB = "pro_32gb"
    PRO64GB = "pro_64gb"
    PRO128GB = "pro_128gb"
    PRO192GB = "pro_192gb"
    PRO256GB = "pro_256gb"
    PRO384GB = "pro_384gb"
    PRO512GB = "pro_512gb"
    ACCELERATED16GB = "accelerated_16gb"
    ACCELERATED32GB = "accelerated_32gb"
    ACCELERATED64GB = "accelerated_64gb"
    ACCELERATED128GB = "accelerated_128gb"
    ACCELERATED256GB = "accelerated_256gb"
    ACCELERATED384GB = "accelerated_384gb"
    ACCELERATED512GB = "accelerated_512gb"
    ACCELERATED768GB = "accelerated_768gb"
    ACCELERATED1024GB = "accelerated_1024gb"


class PostgresRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class PostgresRole(str, Enum):
    PRIMARY = "primary"
    REPLICA = "replica"


class PostgresStatus(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"


class PostgresSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class PostgresSuspendersItem(str, Enum):
    ADMIN = "admin"
    BILLING = "billing"
    USER = "user"
    PARENT_SERVICE = "parent_service"
    UNKNOWN = "unknown"


class PostgresVersion(str, Enum):
    """
    The PostgreSQL version
    """
    POSTGRES_VERSION_11 = "11"
    POSTGRES_VERSION_12 = "12"
    POSTGRES_VERSION_13 = "13"
    POSTGRES_VERSION_14 = "14"
    POSTGRES_VERSION_15 = "15"
    POSTGRES_VERSION_16 = "16"


class RecoverPostgresSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class RedisDetailpropertiesmaintenanceState(str, Enum):
    SCHEDULED = "scheduled"
    IN_PROGRESS = "in_progress"
    USER_FIX_REQUIRED = "user_fix_required"
    CANCELLED = "cancelled"
    SUCCEEDED = "succeeded"
    FAILED = "failed"


class Region(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class Role(str, Enum):
    PRIMARY = "primary"
    REPLICA = "replica"


class Status(str, Enum):
    CREATING = "creating"
    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"
    CONFIG_RESTART = "config_restart"
    SUSPENDED = "suspended"
    MAINTENANCE_SCHEDULED = "maintenance_scheduled"
    MAINTENANCE_IN_PROGRESS = "maintenance_in_progress"
    RECOVERY_FAILED = "recovery_failed"
    RECOVERY_IN_PROGRESS = "recovery_in_progress"
    UNKNOWN = "unknown"
    UPDATING_INSTANCE = "updating_instance"


class Suspended(str, Enum):
    SUSPENDED_ = "suspended"
    NOT_SUSPENDED = "not_suspended"


class SuspendersItem(str, Enum):
    ADMIN = "admin"
    BILLING = "billing"
    USER = "user"
    PARENT_SERVICE = "parent_service"
    UNKNOWN = "unknown"


class Version(str, Enum):
    """
    The PostgreSQL version
    """
    VERSION_11 = "11"
    VERSION_12 = "12"
    VERSION_13 = "13"
    VERSION_14 = "14"
    VERSION_15 = "15"
    VERSION_16 = "16"



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload, Awaitable
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'EnvGroup',
    'AwaitableEnvGroup',
    'get_env_group',
    'get_env_group_output',
]

@pulumi.output_type
class EnvGroup:
    def __init__(__self__, created_at=None, env_vars=None, environment_id=None, id=None, name=None, owner_id=None, secret_files=None, service_links=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if env_vars and not isinstance(env_vars, list):
            raise TypeError("Expected argument 'env_vars' to be a list")
        pulumi.set(__self__, "env_vars", env_vars)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        pulumi.set(__self__, "owner_id", owner_id)
        if secret_files and not isinstance(secret_files, list):
            raise TypeError("Expected argument 'secret_files' to be a list")
        pulumi.set(__self__, "secret_files", secret_files)
        if service_links and not isinstance(service_links, list):
            raise TypeError("Expected argument 'service_links' to be a list")
        pulumi.set(__self__, "service_links", service_links)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="envVars")
    def env_vars(self) -> Sequence['outputs.EnvVar']:
        return pulumi.get(self, "env_vars")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[str]:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> str:
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="secretFiles")
    def secret_files(self) -> Sequence['outputs.SecretFile']:
        return pulumi.get(self, "secret_files")

    @property
    @pulumi.getter(name="serviceLinks")
    def service_links(self) -> Sequence['outputs.ServiceLink']:
        """
        List of serviceIds linked to the envGroup
        """
        return pulumi.get(self, "service_links")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        return pulumi.get(self, "updated_at")


class AwaitableEnvGroup(EnvGroup):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return EnvGroup(
            created_at=self.created_at,
            env_vars=self.env_vars,
            environment_id=self.environment_id,
            id=self.id,
            name=self.name,
            owner_id=self.owner_id,
            secret_files=self.secret_files,
            service_links=self.service_links,
            updated_at=self.updated_at)


def get_env_group(env_group_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableEnvGroup:
    """
    Use this data source to access information about an existing resource.

    :param str env_group_id: Filter for resources that belong to an environment group
    """
    __args__ = dict()
    __args__['envGroupId'] = env_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:env-groups:getEnvGroup', __args__, opts=opts, typ=EnvGroup).value

    return AwaitableEnvGroup(
        created_at=pulumi.get(__ret__, 'created_at'),
        env_vars=pulumi.get(__ret__, 'env_vars'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        owner_id=pulumi.get(__ret__, 'owner_id'),
        secret_files=pulumi.get(__ret__, 'secret_files'),
        service_links=pulumi.get(__ret__, 'service_links'),
        updated_at=pulumi.get(__ret__, 'updated_at'))


@_utilities.lift_output_func(get_env_group)
def get_env_group_output(env_group_id: Optional[pulumi.Input[str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[EnvGroup]:
    """
    Use this data source to access information about an existing resource.

    :param str env_group_id: Filter for resources that belong to an environment group
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .autoscale_service import *
from .background_worker import *
from .cancel_deploy import *
from .cancel_job import *
from .cron_job import *
from .custom_domain import *
from .deploy import *
from .env_vars_for_service import *
from .get_background_worker import *
from .get_cron_job import *
from .get_custom_domain import *
from .get_deploy import *
from .get_env_var import *
from .get_job import *
from .get_private_service import *
from .get_secret_file import *
from .get_static_site import *
from .get_web_service import *
from .header import *
from .job import *
from .list_custom_domains import *
from .list_deploys import *
from .list_env_vars_for_service import *
from .list_headers import *
from .list_job import *
from .list_routes import *
from .list_secret_files_for_service import *
from .list_services import *
from .preview_service import *
from .private_service import *
from .refresh_custom_domain import *
from .restart_service import *
from .rollback_deploy import *
from .route import *
from .scale_service import *
from .secret_files_for_service import *
from .static_site import *
from .suspend_service import *
from .web_service import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload, Awaitable
from .. import _utilities
from ._enums import *

__all__ = [
    'Owner',
    'AwaitableOwner',
    'get_owner',
    'get_owner_output',
]

@pulumi.output_type
class Owner:
    def __init__(__self__, email=None, id=None, name=None, two_factor_auth_enabled=None, type=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if two_factor_auth_enabled and not isinstance(two_factor_auth_enabled, bool):
            raise TypeError("Expected argument 'two_factor_auth_enabled' to be a bool")
        pulumi.set(__self__, "two_factor_auth_enabled", two_factor_auth_enabled)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="twoFactorAuthEnabled")
    def two_factor_auth_enabled(self) -> Optional[bool]:
        """
        Whether two-factor authentication is enabled for the owner. Only present for user owners.
        """
        return pulumi.get(self, "two_factor_auth_enabled")

    @property
    @pulumi.getter
    def type(self) -> 'OwnerType':
        return pulumi.get(self, "type")


class AwaitableOwner(Owner):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return Owner(
            email=self.email,
            id=self.id,
            name=self.name,
            two_factor_auth_enabled=self.two_factor_auth_enabled,
            type=self.type)


def get_owner(owner_id: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableOwner:
    """
    Use this data source to access information about an existing resource.

    :param str owner_id: The ID of the user or team
    """
    __args__ = dict()
    __args__['ownerId'] = owner_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:owners:getOwner', __args__, opts=opts, typ=Owner).value

    return AwaitableOwner(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        two_factor_auth_enabled=pulumi.get(__ret__, 'two_factor_auth_enabled'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_owner)
def get_owner_output(owner_id: Optional[pulumi.Input[str]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[Owner]:
    """
    Use this data source to access information about an existing resource.

    :param str owner_id: The ID of the user or team
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'Registry',
    'RegistryCredentialRegistry',
]


class Registry(str, Enum):
    """
    The registry to use this credential with
    """
    GITHUB = "GITHUB"
    GITLAB = "GITLAB"
    DOCKER = "DOCKER"
    GOOGLE_ARTIFACT = "GOOGLE_ARTIFACT"


class RegistryCredentialRegistry(str, Enum):
    """
    The registry to use this credential with
    """
    GITHUB = "GITHUB"
    GITLAB = "GITLAB"
    DOCKER = "DOCKER"
    GOOGLE_ARTIFACT = "GOOGLE_ARTIFACT"



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._enums import *
from ._inputs import *

__all__ = ['PostgresArgs', 'Postgres']

@pulumi.input_type
class PostgresArgs:
    def __init__(__self__, *,
                 owner_id: pulumi.Input[str],
                 plan: pulumi.Input['Plan'],
                 version: pulumi.Input['Version'],
                 database_name: Optional[pulumi.Input[str]] = None,
                 database_user: Optional[pulumi.Input[str]] = None,
                 datadog_api_key: Optional[pulumi.Input[str]] = None,
                 disk_size_gb: Optional[pulumi.Input[int]] = None,
                 enable_high_availability: Optional[pulumi.Input[bool]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 ip_allow_list: Optional[pulumi.Input[Sequence[pulumi.Input['CidrBlockAndDescriptionArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 read_replicas: Optional[pulumi.Input[Sequence[pulumi.Input['ReadReplicaInputArgs']]]] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Postgres resource.
        :param pulumi.Input[str] owner_id: The ID of the owner (team or personal user) whose resources should be returned
        :param pulumi.Input['Version'] version: The PostgreSQL version
        :param pulumi.Input[int] disk_size_gb: The number of gigabytes of disk space to allocate for the database
        :param pulumi.Input[str] name: The name of the database as it will appear in the Render Dashboard
        """
        pulumi.set(__self__, "owner_id", owner_id)
        pulumi.set(__self__, "plan", plan)
        pulumi.set(__self__, "version", version)
        if database_name is None:
            database_name = 'randomly generated'
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if database_user is None:
            database_user = 'randomly generated'
        if database_user is not None:
            pulumi.set(__self__, "database_user", database_user)
        if datadog_api_key is not None:
            pulumi.set(__self__, "datadog_api_key", datadog_api_key)
        if disk_size_gb is not None:
            pulumi.set(__self__, "disk_size_gb", disk_size_gb)
        if enable_high_availability is None:
            enable_high_availability = False
        if enable_high_availability is not None:
            pulumi.set(__self__, "enable_high_availability", enable_high_availability)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if ip_allow_list is not None:
            pulumi.set(__self__, "ip_allow_list", ip_allow_list)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if read_replicas is not None:
            pulumi.set(__self__, "read_replicas", read_replicas)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> pulumi.Input[str]:
        """
        The ID of the owner (team or personal user) whose resources should be returned
        """
        return pulumi.get(self, "owner_id")

    @owner_id.setter
    def owner_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "owner_id", value)

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Input['Plan']:
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: pulumi.Input['Plan']):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input['Version']:
        """
        The PostgreSQL version
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input['Version']):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="databaseUser")
    def database_user(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "database_user")

    @database_user.setter
    def database_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_user", value)

    @property
    @pulumi.getter(name="datadogAPIKey")
    def datadog_api_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "datadog_api_key")

    @datadog_api_key.setter
    def datadog_api_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "datadog_api_key", value)

    @property
    @pulumi.getter(name="diskSizeGB")
    def disk_size_gb(self) -> Optional[pulumi.Input[int]]:
        """
        The number of gigabytes of disk space to allocate for the database
        """
        return pulumi.get(self, "disk_size_gb")

    @disk_size_gb.setter
    def disk_size_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_size_gb", value)

    @property
    @pulumi.getter(name="enableHighAvailability")
    def enable_high_availability(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enable_high_availability")

    @enable_high_availability.setter
    def enable_high_availability(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_high_availability", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="ipAllowList")
    def ip_allow_list(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CidrBlockAndDescriptionArgs']]]]:
        return pulumi.get(self, "ip_allow_list")

    @ip_allow_list.setter
    def ip_allow_list(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CidrBlockAndDescriptionArgs']]]]):
        pulumi.set(self, "ip_allow_list", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the database as it will appear in the Render Dashboard
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="readReplicas")
    def read_replicas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ReadReplicaInputArgs']]]]:
        return pulumi.get(self, "read_replicas")

    @read_replicas.setter
    def read_replicas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ReadReplicaInputArgs']]]]):
        pulumi.set(self, "read_replicas", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


class Postgres(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 database_user: Optional[pulumi.Input[str]] = None,
                 datadog_api_key: Optional[pulumi.Input[str]] = None,
                 disk_size_gb: Optional[pulumi.Input[int]] = None,
                 enable_high_availability: Optional[pulumi.Input[bool]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 ip_allow_list: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CidrBlockAndDescriptionArgs', 'CidrBlockAndDescriptionArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner_id: Optional[pulumi.Input[str]] = None,
                 plan: Optional[pulumi.Input['Plan']] = None,
                 read_replicas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ReadReplicaInputArgs', 'ReadReplicaInputArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input['Version']] = None,
                 __props__=None):
        """
        Input for creating a database

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] disk_size_gb: The number of gigabytes of disk space to allocate for the database
        :param pulumi.Input[str] name: The name of the database as it will appear in the Render Dashboard
        :param pulumi.Input[str] owner_id: The ID of the owner (team or personal user) whose resources should be returned
        :param pulumi.Input['Version'] version: The PostgreSQL version
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PostgresArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Input for creating a database

        :param str resource_name: The name of the resource.
        :param PostgresArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PostgresArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 database_user: Optional[pulumi.Input[str]] = None,
                 datadog_api_key: Optional[pulumi.Input[str]] = None,
                 disk_size_gb: Optional[pulumi.Input[int]] = None,
                 enable_high_availability: Optional[pulumi.Input[bool]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 ip_allow_list: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CidrBlockAndDescriptionArgs', 'CidrBlockAndDescriptionArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner_id: Optional[pulumi.Input[str]] = None,
                 plan: Optional[pulumi.Input['Plan']] = None,
                 read_replicas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ReadReplicaInputArgs', 'ReadReplicaInputArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input['Version']] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PostgresArgs.__new__(PostgresArgs)

            if database_name is None:
                database_name = 'randomly generated'
            __props__.__dict__["database_name"] = database_name
            if database_user is None:
                database_user = 'randomly generated'
            __props__.__dict__["database_user"] = database_user
            __props__.__dict__["datadog_api_key"] = datadog_api_key
            __props__.__dict__["disk_size_gb"] = disk_size_gb
            if enable_high_availability is None:
                enable_high_availability = False
            __props__.__dict__["enable_high_availability"] = enable_high_availability
            __props__.__dict__["environment_id"] = environment_id
            __props__.__dict__["ip_allow_list"] = ip_allow_list
            __props__.__dict__["name"] = name
            if owner_id is None and not opts.urn:
                raise TypeError("Missing required property 'owner_id'")
            __props__.__dict__["owner_id"] = owner_id
            if plan is None and not opts.urn:
                raise TypeError("Missing required property 'plan'")
            __props__.__dict__["plan"] = plan
            __props__.__dict__["read_replicas"] = read_replicas
            __props__.__dict__["region"] = region
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            __props__.__dict__["created_at"] = None
            __props__.__dict__["dashboard_url"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["high_availability_enabled"] = None
            __props__.__dict__["maintenance"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["primary_postgres_id"] = None
            __props__.__dict__["role"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["suspended"] = None
            __props__.__dict__["suspenders"] = None
            __props__.__dict__["updated_at"] = None
        super(Postgres, __self__).__init__(
            'render:postgres:Postgres',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Postgres':
        """
        Get an existing Postgres resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = PostgresArgs.__new__(PostgresArgs)

        __props__.__dict__["created_at"] = None
        __props__.__dict__["dashboard_url"] = None
        __props__.__dict__["database_name"] = None
        __props__.__dict__["database_user"] = None
        __props__.__dict__["datadog_api_key"] = None
        __props__.__dict__["disk_size_gb"] = None
        __props__.__dict__["enable_high_availability"] = None
        __props__.__dict__["environment_id"] = None
        __props__.__dict__["expires_at"] = None
        __props__.__dict__["high_availability_enabled"] = None
        __props__.__dict__["ip_allow_list"] = None
        __props__.__dict__["maintenance"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["owner"] = None
        __props__.__dict__["owner_id"] = None
        __props__.__dict__["plan"] = None
        __props__.__dict__["primary_postgres_id"] = None
        __props__.__dict__["read_replicas"] = None
        __props__.__dict__["region"] = None
        __props__.__dict__["role"] = None
        __props__.__dict__["status"] = None
        __props__.__dict__["suspended"] = None
        __props__.__dict__["suspenders"] = None
        __props__.__dict__["updated_at"] = None
        __props__.__dict__["version"] = None
        return Postgres(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dashboardUrl")
    def dashboard_url(self) -> pulumi.Output[str]:
        """
        The URL to view the PostgreSQL instance in the Render Dashboard
        """
        return pulumi.get(self, "dashboard_url")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="databaseUser")
    def database_user(self) -> pulumi.Output[str]:
        return pulumi.get(self, "database_user")

    @property
    @pulumi.getter(name="datadogAPIKey")
    def datadog_api_key(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "datadog_api_key")

    @property
    @pulumi.getter(name="diskSizeGB")
    def disk_size_gb(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "disk_size_gb")

    @property
    @pulumi.getter(name="enableHighAvailability")
    def enable_high_availability(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "enable_high_availability")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[Optional[str]]:
        """
        The time at which the database will be expire. Applies to free tier databases only.
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter(name="highAvailabilityEnabled")
    def high_availability_enabled(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "high_availability_enabled")

    @property
    @pulumi.getter(name="ipAllowList")
    def ip_allow_list(self) -> pulumi.Output[Sequence['outputs.CidrBlockAndDescription']]:
        return pulumi.get(self, "ip_allow_list")

    @property
    @pulumi.getter
    def maintenance(self) -> pulumi.Output[Optional['outputs.RedisDetailpropertiesmaintenance']]:
        return pulumi.get(self, "maintenance")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output['outputs.Owner']:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> pulumi.Output[str]:
        """
        The ID of the owner (team or personal user) whose resources should be returned
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output['Plan']:
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter(name="primaryPostgresID")
    def primary_postgres_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "primary_postgres_id")

    @property
    @pulumi.getter(name="readReplicas")
    def read_replicas(self) -> pulumi.Output[Sequence['outputs.ReadReplica']]:
        return pulumi.get(self, "read_replicas")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output['Region']:
        """
        Defaults to "oregon"
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output['Role']:
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['Status']:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def suspended(self) -> pulumi.Output['Suspended']:
        return pulumi.get(self, "suspended")

    @property
    @pulumi.getter
    def suspenders(self) -> pulumi.Output[Sequence['SuspendersItem']]:
        return pulumi.get(self, "suspenders")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output['Version']:
        """
        The PostgreSQL version
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = ['RouteArgs', 'Route']

@pulumi.input_type
class RouteArgs:
    def __init__(__self__, *,
                 destination: pulumi.Input[str],
                 source: pulumi.Input[str],
                 type: pulumi.Input['Type'],
                 priority: Optional[pulumi.Input[int]] = None,
                 service_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Route resource.
        :param pulumi.Input[int] priority: Redirect and Rewrite Rules are applied in priority order starting at 0. Defaults to last in the priority list.
        :param pulumi.Input[str] service_id: The ID of the service
        """
        pulumi.set(__self__, "destination", destination)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "type", type)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter
    def source(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input[str]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input['Type']:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input['Type']):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        Redirect and Rewrite Rules are applied in priority order starting at 0. Defaults to last in the priority list.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the service
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)


class Route(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input['Type']] = None,
                 __props__=None):
        """
        Create a Route resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] priority: Redirect and Rewrite Rules are applied in priority order starting at 0. Defaults to last in the priority list.
        :param pulumi.Input[str] service_id: The ID of the service
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Route resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param RouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input['Type']] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouteArgs.__new__(RouteArgs)

            if destination is None and not opts.urn:
                raise TypeError("Missing required property 'destination'")
            __props__.__dict__["destination"] = destination
            __props__.__dict__["priority"] = priority
            __props__.__dict__["service_id"] = service_id
            if source is None and not opts.urn:
                raise TypeError("Missing required property 'source'")
            __props__.__dict__["source"] = source
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Route, __self__).__init__(
            'render:services:Route',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Route':
        """
        Get an existing Route resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = RouteArgs.__new__(RouteArgs)

        __props__.__dict__["destination"] = None
        __props__.__dict__["priority"] = None
        __props__.__dict__["source"] = None
        __props__.__dict__["type"] = None
        return Route(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Output[str]:
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[int]:
        """
        Redirect and Rewrite Rules are applied in priority order starting at 0
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[str]:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output['Type']:
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload, Awaitable
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'Deploy',
    'AwaitableDeploy',
    'get_deploy',
    'get_deploy_output',
]

@pulumi.output_type
class Deploy:
    def __init__(__self__, commit=None, created_at=None, finished_at=None, id=None, image=None, status=None, trigger=None, updated_at=None):
        if commit and not isinstance(commit, dict):
            raise TypeError("Expected argument 'commit' to be a dict")
        pulumi.set(__self__, "commit", commit)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if finished_at and not isinstance(finished_at, str):
            raise TypeError("Expected argument 'finished_at' to be a str")
        pulumi.set(__self__, "finished_at", finished_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image and not isinstance(image, dict):
            raise TypeError("Expected argument 'image' to be a dict")
        pulumi.set(__self__, "image", image)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if trigger and not isinstance(trigger, str):
            raise TypeError("Expected argument 'trigger' to be a str")
        pulumi.set(__self__, "trigger", trigger)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def commit(self) -> Optional['outputs.DeployCommitProperties']:
        return pulumi.get(self, "commit")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="finishedAt")
    def finished_at(self) -> Optional[str]:
        return pulumi.get(self, "finished_at")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def image(self) -> Optional['outputs.DeployImageProperties']:
        """
        Image information used when creating the deploy. Not present for Git-backed deploys
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter
    def status(self) -> Optional['DeployStatus']:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def trigger(self) -> Optional['DeployTrigger']:
        return pulumi.get(self, "trigger")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[str]:
        return pulumi.get(self, "updated_at")


class AwaitableDeploy(Deploy):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return Deploy(
            commit=self.commit,
            created_at=self.created_at,
            finished_at=self.finished_at,
            id=self.id,
            image=self.image,
            status=self.status,
            trigger=self.trigger,
            updated_at=self.updated_at)


def get_deploy(deploy_id: Optional[str] = None,
               service_id: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableDeploy:
    """
    Use this data source to access information about an existing resource.

    :param str deploy_id: The ID of the deploy
    :param str service_id: The ID of the service
    """
    __args__ = dict()
    __args__['deployId'] = deploy_id
    __args__['serviceId'] = service_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:services:getDeploy', __args__, opts=opts, typ=Deploy).value

    return AwaitableDeploy(
        commit=pulumi.get(__ret__, 'commit'),
        created_at=pulumi.get(__ret__, 'created_at'),
        finished_at=pulumi.get(__ret__, 'finished_at'),
        id=pulumi.get(__ret__, 'id'),
        image=pulumi.get(__ret__, 'image'),
        status=pulumi.get(__ret__, 'status'),
        trigger=pulumi.get(__ret__, 'trigger'),
        updated_at=pulumi.get(__ret__, 'updated_at'))


@_utilities.lift_output_func(get_deploy)
def get_deploy_output(deploy_id: Optional[pulumi.Input[str]] = None,
                      service_id: Optional[pulumi.Input[str]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[Deploy]:
    """
    Use this data source to access information about an existing resource.

    :param str deploy_id: The ID of the deploy
    :param str service_id: The ID of the service
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = ['EnvironmentArgs', 'Environment']

@pulumi.input_type
class EnvironmentArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 protected_status: Optional[pulumi.Input['ProtectedStatus']] = None):
        """
        The set of arguments for constructing a Environment resource.
        :param pulumi.Input['ProtectedStatus'] protected_status: Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        pulumi.set(__self__, "project_id", project_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protected_status is not None:
            pulumi.set(__self__, "protected_status", protected_status)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="protectedStatus")
    def protected_status(self) -> Optional[pulumi.Input['ProtectedStatus']]:
        """
        Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        return pulumi.get(self, "protected_status")

    @protected_status.setter
    def protected_status(self, value: Optional[pulumi.Input['ProtectedStatus']]):
        pulumi.set(self, "protected_status", value)


class Environment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 protected_status: Optional[pulumi.Input['ProtectedStatus']] = None,
                 __props__=None):
        """
        Create a Environment resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input['ProtectedStatus'] protected_status: Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Environment resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param EnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 protected_status: Optional[pulumi.Input['ProtectedStatus']] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentArgs.__new__(EnvironmentArgs)

            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["protected_status"] = protected_status
            __props__.__dict__["databases_ids"] = None
            __props__.__dict__["env_group_ids"] = None
            __props__.__dict__["redis_ids"] = None
            __props__.__dict__["service_ids"] = None
        super(Environment, __self__).__init__(
            'render:environments:Environment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Environment':
        """
        Get an existing Environment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = EnvironmentArgs.__new__(EnvironmentArgs)

        __props__.__dict__["databases_ids"] = None
        __props__.__dict__["env_group_ids"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["project_id"] = None
        __props__.__dict__["protected_status"] = None
        __props__.__dict__["redis_ids"] = None
        __props__.__dict__["service_ids"] = None
        return Environment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="databasesIds")
    def databases_ids(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "databases_ids")

    @property
    @pulumi.getter(name="envGroupIds")
    def env_group_ids(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "env_group_ids")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="protectedStatus")
    def protected_status(self) -> pulumi.Output['ProtectedStatus']:
        """
        Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        return pulumi.get(self, "protected_status")

    @property
    @pulumi.getter(name="redisIds")
    def redis_ids(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "redis_ids")

    @property
    @pulumi.getter(name="serviceIds")
    def service_ids(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "service_ids")




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['RestoreSnapshotArgs', 'RestoreSnapshot']

@pulumi.input_type
class RestoreSnapshotArgs:
    def __init__(__self__, *,
                 snapshot_key: pulumi.Input[str],
                 disk_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RestoreSnapshot resource.
        :param pulumi.Input[str] disk_id: The ID of the disk
        :param pulumi.Input[str] instance_id: When a service with a disk is scaled, the instanceId is used to identify the instance that the disk is attached to. Each instance's disks get their own snapshots, and can be restored separately.
        """
        pulumi.set(__self__, "snapshot_key", snapshot_key)
        if disk_id is not None:
            pulumi.set(__self__, "disk_id", disk_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)

    @property
    @pulumi.getter(name="snapshotKey")
    def snapshot_key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "snapshot_key")

    @snapshot_key.setter
    def snapshot_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "snapshot_key", value)

    @property
    @pulumi.getter(name="diskId")
    def disk_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the disk
        """
        return pulumi.get(self, "disk_id")

    @disk_id.setter
    def disk_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        When a service with a disk is scaled, the instanceId is used to identify the instance that the disk is attached to. Each instance's disks get their own snapshots, and can be restored separately.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)


class RestoreSnapshot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 snapshot_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a RestoreSnapshot resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] disk_id: The ID of the disk
        :param pulumi.Input[str] instance_id: When a service with a disk is scaled, the instanceId is used to identify the instance that the disk is attached to. Each instance's disks get their own snapshots, and can be restored separately.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RestoreSnapshotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a RestoreSnapshot resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param RestoreSnapshotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RestoreSnapshotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 snapshot_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RestoreSnapshotArgs.__new__(RestoreSnapshotArgs)

            __props__.__dict__["disk_id"] = disk_id
            __props__.__dict__["instance_id"] = instance_id
            if snapshot_key is None and not opts.urn:
                raise TypeError("Missing required property 'snapshot_key'")
            __props__.__dict__["snapshot_key"] = snapshot_key
            __props__.__dict__["created_at"] = None
            __props__.__dict__["mount_path"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["size_gb"] = None
            __props__.__dict__["updated_at"] = None
        super(RestoreSnapshot, __self__).__init__(
            'render:disks:RestoreSnapshot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'RestoreSnapshot':
        """
        Get an existing RestoreSnapshot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = RestoreSnapshotArgs.__new__(RestoreSnapshotArgs)

        __props__.__dict__["created_at"] = None
        __props__.__dict__["instance_id"] = None
        __props__.__dict__["mount_path"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["service_id"] = None
        __props__.__dict__["size_gb"] = None
        __props__.__dict__["snapshot_key"] = None
        __props__.__dict__["updated_at"] = None
        return RestoreSnapshot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[Optional[str]]:
        """
        When a service with a disk is scaled, the instanceId is used to identify the instance that the disk is attached to. Each instance's disks get their own snapshots, and can be restored separately.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="mountPath")
    def mount_path(self) -> pulumi.Output[str]:
        return pulumi.get(self, "mount_path")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="sizeGB")
    def size_gb(self) -> pulumi.Output[int]:
        return pulumi.get(self, "size_gb")

    @property
    @pulumi.getter(name="snapshotKey")
    def snapshot_key(self) -> pulumi.Output[str]:
        return pulumi.get(self, "snapshot_key")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ListActiveConnectionsResult',
    'AwaitableListActiveConnectionsResult',
    'list_active_connections',
    'list_active_connections_output',
]

@pulumi.output_type
class ListActiveConnectionsResult:
    def __init__(__self__, items=None):
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.ListActiveConnectionsItemProperties']:
        return pulumi.get(self, "items")


class AwaitableListActiveConnectionsResult(ListActiveConnectionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return ListActiveConnectionsResult(
            items=self.items)


def list_active_connections(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableListActiveConnectionsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('render:metrics:listActiveConnections', __args__, opts=opts, typ=ListActiveConnectionsResult).value

    return AwaitableListActiveConnectionsResult(
        items=pulumi.get(__ret__, 'items'))


@_utilities.lift_output_func(list_active_connections)
def list_active_connections_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[ListActiveConnectionsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = [
    'EnvVarInputArgs',
    'SecretFileInputArgs',
]

@pulumi.input_type
class EnvVarInputArgs:
    def __init__(__self__):
        pass


@pulumi.input_type
class SecretFileInputArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[str],
                 name: pulumi.Input[str]):
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Input[str]:
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[str]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'Environment',
    'EnvironmentWithCursor',
]

@pulumi.output_type
class Environment(dict):
    def __init__(__self__, *,
                 databases_ids: Sequence[str],
                 env_group_ids: Sequence[str],
                 id: str,
                 name: str,
                 project_id: str,
                 protected_status: 'EnvironmentProtectedStatus',
                 redis_ids: Sequence[str],
                 service_ids: Sequence[str]):
        """
        :param 'EnvironmentProtectedStatus' protected_status: Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        pulumi.set(__self__, "databases_ids", databases_ids)
        pulumi.set(__self__, "env_group_ids", env_group_ids)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "protected_status", protected_status)
        pulumi.set(__self__, "redis_ids", redis_ids)
        pulumi.set(__self__, "service_ids", service_ids)

    @property
    @pulumi.getter(name="databasesIds")
    def databases_ids(self) -> Sequence[str]:
        return pulumi.get(self, "databases_ids")

    @property
    @pulumi.getter(name="envGroupIds")
    def env_group_ids(self) -> Sequence[str]:
        return pulumi.get(self, "env_group_ids")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="protectedStatus")
    def protected_status(self) -> 'EnvironmentProtectedStatus':
        """
        Indicates whether an environment is `unprotected` or `protected`. Only admin users can perform destructive actions in `protected` environments.
        """
        return pulumi.get(self, "protected_status")

    @property
    @pulumi.getter(name="redisIds")
    def redis_ids(self) -> Sequence[str]:
        return pulumi.get(self, "redis_ids")

    @property
    @pulumi.getter(name="serviceIds")
    def service_ids(self) -> Sequence[str]:
        return pulumi.get(self, "service_ids")


@pulumi.output_type
class EnvironmentWithCursor(dict):
    """
    An environment with a cursor
    """
    def __init__(__self__, *,
                 cursor: str,
                 environment: 'outputs.Environment'):
        """
        An environment with a cursor
        """
        pulumi.set(__self__, "cursor", cursor)
        pulumi.set(__self__, "environment", environment)

    @property
    @pulumi.getter
    def cursor(self) -> str:
        return pulumi.get(self, "cursor")

    @property
    @pulumi.getter
    def environment(self) -> 'outputs.Environment':
        return pulumi.get(self, "environment")





# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AutoscaleServiceArgs', 'AutoscaleService']

@pulumi.input_type
class AutoscaleServiceArgs:
    def __init__(__self__, *,
                 criteria: pulumi.Input['CriteriaPropertiesArgs'],
                 enabled: Optional[pulumi.Input[bool]] = None,
                 max: pulumi.Input[int],
                 min: pulumi.Input[int],
                 service_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AutoscaleService resource.
        :param pulumi.Input[int] max: The maximum number of instances for the service
        :param pulumi.Input[int] min: The minimum number of instances for the service
        :param pulumi.Input[str] service_id: The ID of the service
        """
        pulumi.set(__self__, "criteria", criteria)
        if enabled is None:
            enabled = False
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "max", max)
        pulumi.set(__self__, "min", min)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)

    @property
    @pulumi.getter
    def criteria(self) -> pulumi.Input['CriteriaPropertiesArgs']:
        return pulumi.get(self, "criteria")

    @criteria.setter
    def criteria(self, value: pulumi.Input['CriteriaPropertiesArgs']):
        pulumi.set(self, "criteria", value)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def max(self) -> pulumi.Input[int]:
        """
        The maximum number of instances for the service
        """
        return pulumi.get(self, "max")

    @max.setter
    def max(self, value: pulumi.Input[int]):
        pulumi.set(self, "max", value)

    @property
    @pulumi.getter
    def min(self) -> pulumi.Input[int]:
        """
        The minimum number of instances for the service
        """
        return pulumi.get(self, "min")

    @min.setter
    def min(self, value: pulumi.Input[int]):
        pulumi.set(self, "min", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the service
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)


class AutoscaleService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 criteria: Optional[pulumi.Input[Union['CriteriaPropertiesArgs', 'CriteriaPropertiesArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 max: Optional[pulumi.Input[int]] = None,
                 min: Optional[pulumi.Input[int]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a AutoscaleService resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] max: The maximum number of instances for the service
        :param pulumi.Input[int] min: The minimum number of instances for the service
        :param pulumi.Input[str] service_id: The ID of the service
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AutoscaleServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AutoscaleService resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AutoscaleServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AutoscaleServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 criteria: Optional[pulumi.Input[Union['CriteriaPropertiesArgs', 'CriteriaPropertiesArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 max: Optional[pulumi.Input[int]] = None,
                 min: Optional[pulumi.Input[int]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AutoscaleServiceArgs.__new__(AutoscaleServiceArgs)

            if criteria is None and not opts.urn:
                raise TypeError("Missing required property 'criteria'")
            __props__.__dict__["criteria"] = criteria
            if enabled is None:
                enabled = False
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if max is None and not opts.urn:
                raise TypeError("Missing required property 'max'")
            __props__.__dict__["max"] = max
            if min is None and not opts.urn:
                raise TypeError("Missing required property 'min'")
            __props__.__dict__["min"] = min
            __props__.__dict__["service_id"] = service_id
        super(AutoscaleService, __self__).__init__(
            'render:services:AutoscaleService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'AutoscaleService':
        """
        Get an existing AutoscaleService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = AutoscaleServiceArgs.__new__(AutoscaleServiceArgs)

        __props__.__dict__["criteria"] = None
        __props__.__dict__["enabled"] = None
        __props__.__dict__["max"] = None
        __props__.__dict__["min"] = None
        return AutoscaleService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def criteria(self) -> pulumi.Output['outputs.CriteriaProperties']:
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def max(self) -> pulumi.Output[int]:
        """
        The maximum number of instances for the service
        """
        return pulumi.get(self, "max")

    @property
    @pulumi.getter
    def min(self) -> pulumi.Output[int]:
        """
        The minimum number of instances for the service
        """
        return pulumi.get(self, "min")

